<?php

/* * ***********************
 * Intialization functions
 * ********************** */
add_action('init', 'possibly_redirect');
add_option('pass_change', 'false', '', 'yes');

function clearExpiredPosts()
{
    global $post;
    $all = get_posts("posts_per_page=500");

    foreach ($all as $post) :
        setup_postdata($post);
        $exp = get_post_meta($post->ID, "exp_value", true);
        if ($exp != 'noexpire')
        {
            $expired = str_replace("/", "", $exp);
            if ($expired < date("Ymd"))
            {
			echo 
                wp_delete_post($post->ID);
            }
        }
    endforeach;
    wp_reset_query();
}

register_nav_menus(array(
    'footer' => __('Footer', 'ninetofive'),
));

add_theme_support("post-thumbnails");

if (function_exists('register_sidebar'))
{
    register_sidebar(array(
        'before_widget' => '<li class="widget">',
        'after_widget' => '</li>',
        'before_title' => '<h2 class="widgettitle">',
        'after_title' => '</h2>',
    ));
}

if (get_option("9t5_wp_login") != "")
{

    function my_custom_login_logo()
    {
        echo '<style type="text/css">h1 a { background-image:url(' . get_option("9t5_wp_login") . ') !important; } </style>';
    }

    add_action('login_head', 'my_custom_login_logo');
}

register_post_type('blog', array(
    'label' => __('Blog Posts', '9to5'),
    'singular_label' => __('Blog Post', '9to5'),
    'public' => true,
    'show_ui' => true,
    'capability_type' => 'post',
    'hierarchical' => false,
    'rewrite' => true,
    'rewrite' => array(
        'slug' => 'blog',
        'with_front' => FALSE,
    ),
    'query_var' => false,
    'supports' => array('title', 'editor', 'author', 'excerpt', 'trackbacks', 'custom-fields', 'comments', 'revisions'),
    'menu_position' => 5
));

flush_rewrite_rules();

function mytheme_add_init()
{
    $file_dir = get_bloginfo('template_directory');
    wp_enqueue_style("functions", $file_dir . "/functions.css", false, "1.0", "all");
}

/* * *****************
 * Load localization
 * **************** */
load_theme_textdomain('9to5', TEMPLATEPATH . '/languages');
$locale = get_locale();
$locale_file = TEMPLATEPATH . "/languages/$locale.php";
if (is_readable($locale_file))
    require_once($locale_file);

/* * ************************************************
 * Redirection of standart wordpress auth functions
 * *********************************************** */

function possibly_redirect()
{
    global $pagenow;
    if ('wp-login.php' == $pagenow && $_REQUEST['action'] != 'logout')
    {
        if ($_REQUEST['action'] == 'lostpassword')
        {
            wp_redirect(get_bloginfo('wpurl') . '/lostpassword/');
            exit();
        }
        elseif ($_REQUEST['action'] == 'rp')
        {
            update_option('pass_change', 'true');
        }
    }
}

/**

 * Validation of auth-provided data
 *
 * @global array $auth_errors Output validation errors
 * @param string $type Action type
 * @param array $parameters Validation parameters

 * @return bool Validation status
 */
function auth_validation($type, $parameters)
{
    global $auth_errors;

    if ($type == 'login')
    {
        $counter = 0;
        if (empty($parameters['username']) || empty($parameters['password']))
        {
            $auth_errors[] = __('Fields "Username" and "Password" are required.', '9to5');
            $counter++;
        }
        if (!preg_match("/^[-a-zA-Z0-9]+$/", $parameters['username']))
        {
            $auth_errors[] = __('"Username" may contain only A-Z,a-z,0-9.', '9to5');
            $counter++;
        }
        if ($counter != 0)
            return FALSE;
        return TRUE;
    }
    elseif ($type == 'register')
    {
        $counter = 0;

        require_once(ABSPATH . WPINC . '/registration.php');

        if (empty($parameters['username']) || empty($parameters['password']) || empty($parameters['email']))
        {
            $auth_errors[] = __('Fields "Username", "Password" and "Email" are required.', '9to5');
            $counter++;
        }
        if (!preg_match("/^[-a-zA-Z0-9]+$/", $parameters['username']))
        {
            $auth_errors[] = __('"Username" may contain only A-Z,a-z,0-9.', '9to5');
            $counter++;
        }
        if (!is_email($parameters['email']))
        {
            $auth_errors[] = __('Invalid email format.', '9to5');
            $counter++;
        }
        if (username_exists($parameters['username']))
        {
            $auth_errors[] = __('This username already taken.', '9to5');
            $counter++;
        }
        if (email_exists($parameters['email']))
        {
            $auth_errors[] = __('This email already registered.', '9to5');
            $counter++;
        }
        if ($counter != 0)
            return FALSE;
        return TRUE;
    }
}

/* * ***********
 * Job posting
 * ********** */
if ($_REQUEST['action'] == 'postajob')
{
    global $current_user;
    get_currentuserinfo();

    // Recive POST data
    $positionType = $_POST['position_type_value'];
    $jobCategory = $_POST['category'];
    $jobTitle = format_to_post($_POST['post_title']);
    $jobDescription = format_to_post($_POST['content']);
    $companyName = format_to_post($_POST['company_name_value']);
    $jobLocation = format_to_post($_POST['location_value']);
    if (get_option('9t5_job_salary') == 'Yes')
    {
        if($_POST['salary'] != '' && $_POST['salary'] != __('e.g. $1500 a month or 25 USD per hour', '9to5'))
        {
            $jobSalary = format_to_post($_POST['salary']);
        }
        if($_POST['salary'] != '')
        {
            $salaryDescription = format_to_post($_POST['salary_description']);
        }
    }

    $jobLocation = format_to_post($_POST['location_value']);
    $googleMap = $_POST['map'];
    $jobTags = $_POST['post_tags'];
    if (isset($_POST['noexpire']))
    {
        $expireDate = 'noexpire';
    }
    else
    {
        $expireDate = $_POST['expdate'];
    }
    $howToApply = format_to_post($_POST['how_to_apply_value']);
    $enableApply = $_POST['enableApply'];
    $applicationEmail = $_POST['application_email'];
    $applicationEmailMessage = format_to_post($_POST['application_email_message']);
    $maxSkills = get_option("9t5_max_skills") + 1;
    $jobSkills = array();
    $counter = 1;
    while ($maxSkills > $counter)
    {
        $selector = 'skills_value_' . $counter;
        if (!empty($_POST[$selector]))
        {
            $jobSkills[] = $_POST[$selector];
        }
        $counter++;
    }
    $jobSkills = implode(',', $jobSkills);
    if ($enableApply == 'enableApply')
    {
        $enableApply = 'yes';
    }
    if (isset($_POST['anon']))
    {
        $companyName = __('Anonymous', '9to5');
    }
    if (isset($_POST['anywhere']))
    {
        $jobLocation = __('Anywhere', '9to5');
    }

    // Creation of post object
    $my_post = array(
        'post_title' => $jobTitle,
        'post_content' => $jobDescription,
        'post_status' => 'publish',
        'post_author' => $current_user->ID,
        'post_category' => array($jobCategory),
        'tags_input' => $jobTags
    );
    $post_id = wp_insert_post($my_post);

    // Add post meta data
    add_post_meta($post_id, 'position_type_value', $positionType);
    add_post_meta($post_id, 'company_name_value', $companyName);
    add_post_meta($post_id, 'enableapply_value', $enableApply);
    add_post_meta($post_id, 'exp_value', $expireDate);
    add_post_meta($post_id, 'how_to_apply_value', $howToApply);
    add_post_meta($post_id, 'location_value', $jobLocation);
    add_post_meta($post_id, 'position_type_value', $positionType);
    add_post_meta($post_id, 'skills_value', $jobSkills);
    add_post_meta($post_id, 'map_value', $googleMap);
    add_post_meta($post_id, 'email_value', $applicationEmail);
    add_post_meta($post_id, 'email_message_value', $applicationEmailMessage);
    if($jobSalary) add_post_meta($post_id, 'salary_value', $jobSalary);
    if($salaryDescription) add_post_meta($post_id, 'salary_description_value', $salaryDescription);

    // Redirect to added job
    $post_url = get_permalink($post_id);
    wp_redirect($post_url);
    exit();
}

/**
 * Reload of a standart wordpress auth functions
 */
if ('registration' == $_REQUEST['action'])
{
    global $auth_errors;

    $username = trim($_REQUEST['regusername']);
    $password = trim($_REQUEST['regpassword']);
    $email = trim($_REQUEST['regemail']);

    $parameters['username'] = $username;
    $parameters['password'] = $password;
    $parameters['email'] = $email;

    if (auth_validation('register', $parameters))
    {
        /*
         * Creation of a new user
         */
        require_once(ABSPATH . WPINC . '/registration.php');
        wp_create_user($username, $password, $email);
        wp_signon(array('user_login' => $username, 'user_password' => $password, 'remember' => 'true'), false);
        wp_redirect(get_bloginfo('wpurl') . '/post-a-job/');
        exit();
    }
}
elseif ('login' == $_REQUEST['action'])
{

    global $auth_errors;

    $username = trim($_REQUEST['username']);
    $password = trim($_REQUEST['password']);

    $parameters['username'] = $username;
    $parameters['password'] = $password;

    if (auth_validation('login', $parameters))
    {
        /*
         * User sign in
         */
        if (is_wp_error(wp_signon(array('user_login' => $username, 'user_password' => $password, 'remember' => 'true'), false)))
        {
            $auth_errors[] = __('Invalid username or password.', '9to5');
        }
        else
        {
            wp_redirect(get_bloginfo('wpurl') . '/post-a-job/');
            exit();
        }
    }
}
elseif ('lost' == $_REQUEST['action'])
{
    /**
     * Restoring user password
     */
    global $auth_errors;
    global $auth_messages;

    $counter = 0;

    if (empty($_REQUEST['ident']))
    {
        $auth_errors[] = __('Please, specify your username or email.', '9to5');
        $counter++;
    }
    if (strpos($_REQUEST['ident'], '@'))
    {
        $user_data = get_user_by_email(trim($_REQUEST['ident']));
        if (empty($user_data) && $counter == 0)
        {
            $auth_errors[] = __('User with such email not found.', '9to5');
            $counter++;
        }
    }
    else
    {
        $login = trim($_REQUEST['ident']);
        $user_data = get_userdatabylogin($login);
    }

    do_action('lostpassword_post');

    if (!$user_data && $counter == 0)
    {
        $auth_errors[] = __('User with such username not found.', '9to5');
        $counter++;
    }

    // redefining user_login ensures we return the right case in the email
    $user_login = $user_data->user_login;
    $user_email = $user_data->user_email;

    do_action('retreive_password', $user_login);  // Misspelled and deprecated
    do_action('retrieve_password', $user_login);

    $allow = apply_filters('allow_password_reset', true, $user_data->ID);

    if (!$allow && $counter == 0)
    {
        $auth_errors[] = __('User with such username not found.', '9to5');
        $counter++;
    }
    if ($counter == 0)
    {
        $key = $wpdb->get_var($wpdb->prepare("SELECT user_activation_key FROM $wpdb->users WHERE user_login = %s", $user_login));

        if (empty($key))
        {
            // Generate something random for a key...
            $key = wp_generate_password(20, false);
            do_action('retrieve_password_key', $user_login, $key);
            // Now insert the new md5 key into the db
            $wpdb->update($wpdb->users, array('user_activation_key' => $key), array('user_login' => $user_login));
        }
        $message = __('Someone has asked to reset the password for the following site and username.', '9to5') . "\r\n\r\n";
        $message .= network_site_url() . "\r\n\r\n";
        $message .= sprintf(__('Username: %s', '9to5'), $user_login) . "\r\n\r\n";
        $message .= __('To reset your password visit the following address, otherwise just ignore this email and nothing will happen.', '9to5') . "\r\n\r\n";
        $message .= network_site_url("wp-login.php?action=rp&key=$key&login=" . rawurlencode($user_login), 'login') . "\r\n";

        // The blogname option is escaped with esc_html on the way into the database in sanitize_option
        // we want to reverse this for the plain text arena of emails.
        $blogname = wp_specialchars_decode(get_option('blogname'), ENT_QUOTES);

        $title = sprintf(__('[%s] Password Reset', '9to5'), $blogname);

        $title = apply_filters('retrieve_password_title', $title);
        $message = apply_filters('retrieve_password_message', $message, $key);

        if ($message && !wp_mail($user_email, $title, $message))
            wp_die(__('The email could not be sent.', '9to5') . "<br />\n" . __('Possible reason: your host may have disabled the mail() function...', '9to5'));

        $auth_messages[] = __('Please, check your email.', '9to5');
    }
}

/* * *************
 * Theme options
 * ************ */
$themename = "Nine to Five";
$shortname = "9t5";

/**
 * Load options description
 */
if (isset($_GET['page']) == basename(__FILE__))
{
    include('scripts/themeoptions.php');
}

/**
 * If theme is just installed - register settings
 */
if (get_option('9t5_version') != '4')
{
    include('scripts/initconfig.php');
}

/* * **********
 * Admin page
 * ********* */

function mytheme_add_admin()
{
    global $themename, $shortname, $options;
    add_menu_page($themename, $themename . ' Settings', 'administrator', basename(__FILE__), 'mytheme_admin');
}

if (isset($_GET['page']) == basename(__FILE__))
{
    include('scripts/adminfunctions.php');
    include('scripts/adminpage.php');
}

add_action('admin_init', 'mytheme_add_init');
add_action('admin_menu', 'mytheme_add_admin');

/* * *****************
 * Custom meta boxes
 * **************** */
if (is_admin ())
{
    include('scripts/metaboxes.php');
}
?>
